service

package
v1.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2026 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CachedGraphQLService

type CachedGraphQLService struct {
	// contains filtered or unexported fields
}

CachedGraphQLService implements GraphQLService with an in-memory schema cache

func NewCachedGraphQLService

func NewCachedGraphQLService() *CachedGraphQLService

NewCachedGraphQLService creates a new GraphQL service with caching

func (*CachedGraphQLService) ExecuteQuery

func (s *CachedGraphQLService) ExecuteQuery(catalog string, catalogFS fs.FS, query string) (*graphql.Result, error)

ExecuteQuery executes a GraphQL query against a catalog

func (*CachedGraphQLService) GetSchema

func (s *CachedGraphQLService) GetSchema(catalog string, catalogFS fs.FS) (*gql.DynamicSchema, error)

GetSchema returns the GraphQL schema for a catalog, using cache if available

func (*CachedGraphQLService) InvalidateCache

func (s *CachedGraphQLService) InvalidateCache(catalog string)

InvalidateCache removes the cached schema for a catalog

type GraphQLService

type GraphQLService interface {
	// GetSchema returns the GraphQL schema for a catalog, using cache if available
	GetSchema(catalog string, catalogFS fs.FS) (*gql.DynamicSchema, error)

	// ExecuteQuery executes a GraphQL query against a catalog
	ExecuteQuery(catalog string, catalogFS fs.FS, query string) (*graphql.Result, error)

	// InvalidateCache removes the cached schema for a catalog
	InvalidateCache(catalog string)
}

GraphQLService handles GraphQL schema generation and query execution for catalogs

Jump to