registry

package
v1.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2026 License: Apache-2.0 Imports: 24 Imported by: 0

Documentation

Overview

Package registry provides functions to deploy an OCI image registry in a Kubernetes cluster for e2e testing.

Index

Constants

const (
	DefaultNamespace = "operator-controller-e2e"
	DefaultName      = "docker-registry"
)

Variables

This section is empty.

Functions

func Deploy

func Deploy(ctx context.Context, cfg *rest.Config, namespace, name string) error

Deploy ensures the image registry namespace, TLS certificate, deployment, and service exist in the cluster. It is idempotent — if the resources already exist, they are updated in place via server-side apply.

func PortForward

func PortForward(ctx context.Context, cfg *rest.Config, namespace, name string) (string, func(), error)

PortForward establishes a port-forward to the registry pod and returns the local address (e.g. "localhost:12345") that can be used to push images. The returned stop function should be called to clean up the port-forward.

Types

This section is empty.

Jump to