summary

package
v1.10.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2026 License: Apache-2.0 Imports: 22 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CollectTestArtifacts

func CollectTestArtifacts(t *testing.T, artifactName string, c client.Client, cfg *rest.Config)

CollectTestArtifacts gets all the artifacts from the test run and saves them to the artifact path. Currently, it saves: - clusterextensions - clusterobjectsets - pods logs - deployments - catalogsources

func NewSummary

func NewSummary(c api.Client, pods ...string) githubSummary

func PrintSummary

func PrintSummary(path string) error

PrintSummary executes the main summary template, generating the full test report. The markdown is template-driven; the summary methods are called from within the template. This allows us to add or change queries (hopefully) without needing to touch code. The summary will be output to a file supplied by the env target.

Types

This section is empty.

Jump to