Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CollectTestArtifacts ¶
CollectTestArtifacts gets all the artifacts from the test run and saves them to the artifact path. Currently, it saves: - clusterextensions - clusterobjectsets - pods logs - deployments - catalogsources
func NewSummary ¶
func PrintSummary ¶
PrintSummary executes the main summary template, generating the full test report. The markdown is template-driven; the summary methods are called from within the template. This allows us to add or change queries (hopefully) without needing to touch code. The summary will be output to a file supplied by the env target.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.